@@ -7,6 +7,8 @@ from prefect import task, Task
 
 from typing import Optional
 
+from .constants.env import PROD, DEV
+
 
 def get_dsn(fallback: str = "data/dw-credentials.txt") -> Optional[str]:
     try:
@@ -16,10 +18,10 @@ def get_dsn(fallback: str = "data/dw-credentials.txt") -> Optional[str]:
             return f.read()
 
 
-def get_red_credentials(env="prod"):
-    if env == "prod":
+def get_red_credentials(env=PROD):
+    if env == PROD:
         path = "data/dw-redshift-prod-credentials.json"
-    elif env == "dev":
+    elif env == DEV:
         path = "data/dw-redshift-dev-credentials.json"
 
     with open(path) as f:
