@@ -14,9 +14,13 @@ def get_associations(hapikey, app_private_token, fromType, toType, ids, tries=5)
         headers = {"content-type": "application/json", "cache-control": "no-cache"}
 
     else:
-        parameter_dict = {"a":"a"}
-        headers = {"content-type": "application/json", "cache-control": "no-cache", 'Authorization': f"Bearer {app_private_token}"}
-        
+        parameter_dict = {"a": "a"}
+        headers = {
+            "content-type": "application/json",
+            "cache-control": "no-cache",
+            "Authorization": f"Bearer {app_private_token}",
+        }
+
     parameters = urllib.parse.urlencode(parameter_dict)
 
     body = json.dumps({"inputs": ids})
@@ -29,10 +33,12 @@ def get_associations(hapikey, app_private_token, fromType, toType, ids, tries=5)
 
             return response_dict
         except Exception as e:
-            prefect.context.logger.error(e)
+            prefect.get_run_logger().error(e)
 
 
-def get_all_associations(hapikey, app_private_token, fromType, toType, ids, batch_size=5000):
+def get_all_associations(
+    hapikey, app_private_token, fromType, toType, ids, batch_size=5000
+):
     list_df = [ids[i : i + batch_size] for i in range(0, len(ids), batch_size)]
 
     for i in list_df:
@@ -40,4 +46,4 @@ def get_all_associations(hapikey, app_private_token, fromType, toType, ids, batc
             resp = get_associations(hapikey, app_private_token, fromType, toType, i)
             yield resp["results"]
         except Exception as e:
-            prefect.context.logger.error(e)
+            prefect.get_run_logger().error(e)
