@@ -2,7 +2,11 @@ import requests
 
 
 def check_flow_already_running_on_another_call(
-    prefect_api_key, prefect_api_url, deployment_id=None, deployment_name=None
+    prefect_api_key,
+    prefect_api_url,
+    deployment_id=None,
+    deployment_name=None,
+    check_parameters=None,
 ):
     if deployment_id is None and deployment_name is None:
         return False
@@ -33,6 +37,21 @@ def check_flow_already_running_on_another_call(
     flow_runs = response.json()
 
     if len(flow_runs) > 1:  # 1 because the flow is running on this call
-        return True
+        if check_parameters is not None:
+            return __check_parameters(flow_runs, check_parameters)
+        else:
+            return True
     else:
         return False
+
+
+def __check_parameters(flow_runs, check_parameters):
+    for flow_run in flow_runs:
+        if all(
+            [
+                flow_run["parameters"][key] == check_parameters[key]
+                for key in check_parameters
+            ]
+        ):
+            return False
+    return True
